# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/cluster.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x15grid/v1/cluster.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x92\x01\n\x07\x43luster\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12(\n\x04spec\x18\x02 \x01(\x0b\x32\x14.grid.v1.ClusterSpecR\x04spec\x12.\n\x06status\x18\x03 \x01(\x0b\x32\x16.grid.v1.ClusterStatusR\x06status\"\xbb\x02\n\x0b\x43lusterSpec\x12.\n\x06\x64river\x18\x01 \x01(\x0b\x32\x16.grid.v1.ClusterDriverR\x06\x64river\x12)\n\x10pause_automation\x18\x02 \x01(\x08R\x0fpauseAutomation\x12\x1a\n\x08internal\x18\x03 \x01(\x08R\x08internal\x12:\n\rdesired_state\x18\x04 \x01(\x0e\x32\x15.grid.v1.ClusterStateR\x0c\x64\x65siredState\x12\'\n\x0fgridlet_version\x18\x05 \x01(\tR\x0egridletVersion\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12\x37\n\x0c\x63luster_type\x18\x07 \x01(\x0e\x32\x14.grid.v1.ClusterTypeR\x0b\x63lusterType\"\xc6\x01\n\rClusterDriver\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x42\n\nkubernetes\x18\x02 \x01(\x0b\x32 .grid.v1.KubernetesClusterDriverH\x00R\nkubernetes\x12\x33\n\x05slurm\x18\x03 \x01(\x0b\x32\x1b.grid.v1.SlurmClusterDriverH\x00R\x05slurmB\x08\n\x06\x64river\"\x96\x02\n\x17KubernetesClusterDriver\x12\x31\n\x03\x61ws\x18\x01 \x01(\x0b\x32\x1d.grid.v1.AWSClusterDriverSpecH\x00R\x03\x61ws\x12=\n\nkubeconfig\x18\x02 \x01(\x0b\x32\x1b.grid.v1.ExternalKubeconfigH\x00R\nkubeconfig\x12\x37\n\x05\x61zure\x18\x05 \x01(\x0b\x32\x1f.grid.v1.AzureClusterDriverSpecH\x00R\x05\x61zure\x12(\n\x10root_domain_name\x18\x03 \x01(\tR\x0erootDomainName\x12\x1c\n\tnamespace\x18\x04 \x01(\tR\tnamespaceB\x08\n\x06\x64river\"\x96\x04\n\x14\x41WSClusterDriverSpec\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12\x19\n\x08role_arn\x18\x02 \x01(\tR\x07roleArn\x12\x1f\n\x0b\x65xternal_id\x18\x03 \x01(\tR\nexternalId\x12-\n\x12kubernetes_version\x18\x04 \x01(\tR\x11kubernetesVersion\x12<\n\x0einstance_types\x18\x05 \x03(\x0b\x32\x15.grid.v1.InstanceSpecR\rinstanceTypes\x12\x32\n\x15original_cluster_name\x18\x06 \x01(\tR\x13originalClusterName\x12\x1f\n\x0b\x62ucket_name\x18\x07 \x01(\tR\nbucketName\x12.\n\x13\x65nable_dns_firewall\x18\x10 \x01(\x08R\x11\x65nableDnsFirewall\x12&\n\x0finternal_gc_ttl\x18\x11 \x01(\tR\rinternalGcTtl\x12\x32\n\x15internal_test_cluster\x18\x12 \x01(\x08R\x13internalTestCluster\x12\x33\n\x15guardduty_integration\x18\x13 \x01(\x08R\x14guarddutyIntegration\x12\'\n\x10x_multi_az_count\x18\x15 \x01(\x05R\rxMultiAzCount\"\xfa\x01\n\x16\x41zureClusterDriverSpec\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\x12\'\n\x0fsubscription_id\x18\x02 \x01(\tR\x0esubscriptionId\x12-\n\x12kubernetes_version\x18\x04 \x01(\tR\x11kubernetesVersion\x12<\n\x0einstance_types\x18\x05 \x03(\x0b\x32\x15.grid.v1.InstanceSpecR\rinstanceTypes\x12\x32\n\x15internal_test_cluster\x18\x12 \x01(\x08R\x13internalTestCluster\"\"\n\x0cInstanceSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"4\n\x12\x45xternalKubeconfig\x12\x1e\n\nkubeconfig\x18\x01 \x01(\tR\nkubeconfig\"\x14\n\x12SlurmClusterDriver\"\xf1\x01\n\rClusterStatus\x12\x41\n\rdriver_status\x18\x01 \x01(\x0b\x32\x1c.grid.v1.ClusterDriverStatusR\x0c\x64riverStatus\x12+\n\x05phase\x18\x02 \x01(\x0e\x32\x15.grid.v1.ClusterStateR\x05phase\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12X\n\x1alast_healthcheck_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x18lastHealthcheckTimestamp\"\xcc\x01\n\x13\x43lusterDriverStatus\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x42\n\nkubernetes\x18\x02 \x01(\x0b\x32 .grid.v1.KubernetesClusterStatusH\x00R\nkubernetes\x12\x33\n\x05slurm\x18\x03 \x01(\x0b\x32\x1b.grid.v1.SlurmClusterStatusH\x00R\x05slurmB\x08\n\x06status\"\xf6\x03\n\x17KubernetesClusterStatus\x12&\n\x0f\x62\x61stion_host_ip\x18\x02 \x01(\tR\rbastionHostIp\x12$\n\x0essh_public_key\x18\x03 \x01(\tR\x0csshPublicKey\x12&\n\x0fssh_private_key\x18\x04 \x01(\tR\rsshPrivateKey\x12\x32\n\x03\x65ks\x18\x05 \x01(\x0b\x32\x1e.grid.v1.EKSCusterDriverStatusH\x00R\x03\x65ks\x12\x39\n\x05\x61zure\x18\t \x01(\x0b\x32!.grid.v1.AzureClusterDriverStatusH\x00R\x05\x61zure\x12\x45\n\x1eingress_load_balancer_hostname\x18\x06 \x01(\tH\x01R\x1bingressLoadBalancerHostname\x12\x39\n\x18ingress_load_balancer_ip\x18\x07 \x01(\tH\x01R\x15ingressLoadBalancerIp\x12\x30\n\x14ssh_gateway_hostname\x18\x08 \x01(\tR\x12sshGatewayHostname\x12&\n\x0fingress_ca_cert\x18\n \x01(\x0cR\ringressCaCertB\x0f\n\rdriver_statusB\t\n\x07ingress\"\xe3\x01\n\x15\x45KSCusterDriverStatus\x12(\n\x10gridlet_role_arn\x18\x02 \x01(\tR\x0egridletRoleArn\x12\x33\n\x16user_workload_role_arn\x18\x03 \x01(\tR\x13userWorkloadRoleArn\x12&\n\x0f\x65\x63r_registry_id\x18\x04 \x01(\tR\recrRegistryId\x12,\n\x12\x65\x63r_repository_uri\x18\x05 \x01(\tR\x10\x65\x63rRepositoryUri\x12\x15\n\x06vpc_id\x18\x06 \x01(\tR\x05vpcId\"\x1a\n\x18\x41zureClusterDriverStatus\"\x14\n\x12SlurmClusterStatus*t\n\x0b\x43lusterType\x12\x1c\n\x18\x43LUSTER_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43LUSTER_TYPE_LEGACY\x10\x01\x12\x17\n\x13\x43LUSTER_TYPE_GLOBAL\x10\x02\x12\x15\n\x11\x43LUSTER_TYPE_BYOC\x10\x03*\xb2\x01\n\x0c\x43lusterState\x12\x1d\n\x19\x43LUSTER_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LUSTER_STATE_PENDING\x10\x01\x12\x18\n\x14\x43LUSTER_STATE_QUEUED\x10\x02\x12\x19\n\x15\x43LUSTER_STATE_RUNNING\x10\x03\x12\x18\n\x14\x43LUSTER_STATE_FAILED\x10\x04\x12\x19\n\x15\x43LUSTER_STATE_DELETED\x10\x05\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_CLUSTERTYPE = _descriptor.EnumDescriptor(
    name='ClusterType',
    full_name='grid.v1.ClusterType',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_TYPE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_TYPE_LEGACY',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_TYPE_GLOBAL',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_TYPE_BYOC',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3205,
    serialized_end=3321,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERTYPE)

ClusterType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTYPE)
_CLUSTERSTATE = _descriptor.EnumDescriptor(
    name='ClusterState',
    full_name='grid.v1.ClusterState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_PENDING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_QUEUED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_RUNNING',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_FAILED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='CLUSTER_STATE_DELETED',
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3324,
    serialized_end=3502,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERSTATE)

ClusterState = enum_type_wrapper.EnumTypeWrapper(_CLUSTERSTATE)
CLUSTER_TYPE_UNSPECIFIED = 0
CLUSTER_TYPE_LEGACY = 1
CLUSTER_TYPE_GLOBAL = 2
CLUSTER_TYPE_BYOC = 3
CLUSTER_STATE_UNSPECIFIED = 0
CLUSTER_STATE_PENDING = 1
CLUSTER_STATE_QUEUED = 2
CLUSTER_STATE_RUNNING = 3
CLUSTER_STATE_FAILED = 4
CLUSTER_STATE_DELETED = 5

_CLUSTER = _descriptor.Descriptor(
    name='Cluster',
    full_name='grid.v1.Cluster',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Cluster.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Cluster.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Cluster.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=119,
    serialized_end=265,
)

_CLUSTERSPEC = _descriptor.Descriptor(
    name='ClusterSpec',
    full_name='grid.v1.ClusterSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='driver',
            full_name='grid.v1.ClusterSpec.driver',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='driver',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='pause_automation',
            full_name='grid.v1.ClusterSpec.pause_automation',
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='pauseAutomation',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal',
            full_name='grid.v1.ClusterSpec.internal',
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internal',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.ClusterSpec.desired_state',
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='gridlet_version',
            full_name='grid.v1.ClusterSpec.gridlet_version',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='gridletVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ClusterSpec.user_id',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_type',
            full_name='grid.v1.ClusterSpec.cluster_type',
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=268,
    serialized_end=583,
)

_CLUSTERDRIVER = _descriptor.Descriptor(
    name='ClusterDriver',
    full_name='grid.v1.ClusterDriver',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ClusterDriver.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes',
            full_name='grid.v1.ClusterDriver.kubernetes',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='slurm',
            full_name='grid.v1.ClusterDriver.slurm',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='slurm',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='driver',
            full_name='grid.v1.ClusterDriver.driver',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=586,
    serialized_end=784,
)

_KUBERNETESCLUSTERDRIVER = _descriptor.Descriptor(
    name='KubernetesClusterDriver',
    full_name='grid.v1.KubernetesClusterDriver',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='aws',
            full_name='grid.v1.KubernetesClusterDriver.aws',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='aws',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubeconfig',
            full_name='grid.v1.KubernetesClusterDriver.kubeconfig',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubeconfig',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='azure',
            full_name='grid.v1.KubernetesClusterDriver.azure',
            index=2,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='azure',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='root_domain_name',
            full_name='grid.v1.KubernetesClusterDriver.root_domain_name',
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='rootDomainName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='namespace',
            full_name='grid.v1.KubernetesClusterDriver.namespace',
            index=4,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='namespace',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='driver',
            full_name='grid.v1.KubernetesClusterDriver.driver',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=787,
    serialized_end=1065,
)

_AWSCLUSTERDRIVERSPEC = _descriptor.Descriptor(
    name='AWSClusterDriverSpec',
    full_name='grid.v1.AWSClusterDriverSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='region',
            full_name='grid.v1.AWSClusterDriverSpec.region',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='region',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='role_arn',
            full_name='grid.v1.AWSClusterDriverSpec.role_arn',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='roleArn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='external_id',
            full_name='grid.v1.AWSClusterDriverSpec.external_id',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='externalId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes_version',
            full_name='grid.v1.AWSClusterDriverSpec.kubernetes_version',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetesVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='instance_types',
            full_name='grid.v1.AWSClusterDriverSpec.instance_types',
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='instanceTypes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='original_cluster_name',
            full_name='grid.v1.AWSClusterDriverSpec.original_cluster_name',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='originalClusterName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='bucket_name',
            full_name='grid.v1.AWSClusterDriverSpec.bucket_name',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='bucketName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='enable_dns_firewall',
            full_name='grid.v1.AWSClusterDriverSpec.enable_dns_firewall',
            index=7,
            number=16,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='enableDnsFirewall',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal_gc_ttl',
            full_name='grid.v1.AWSClusterDriverSpec.internal_gc_ttl',
            index=8,
            number=17,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internalGcTtl',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal_test_cluster',
            full_name='grid.v1.AWSClusterDriverSpec.internal_test_cluster',
            index=9,
            number=18,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internalTestCluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='guardduty_integration',
            full_name='grid.v1.AWSClusterDriverSpec.guardduty_integration',
            index=10,
            number=19,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='guarddutyIntegration',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='x_multi_az_count',
            full_name='grid.v1.AWSClusterDriverSpec.x_multi_az_count',
            index=11,
            number=21,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='xMultiAzCount',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1068,
    serialized_end=1602,
)

_AZURECLUSTERDRIVERSPEC = _descriptor.Descriptor(
    name='AzureClusterDriverSpec',
    full_name='grid.v1.AzureClusterDriverSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='region',
            full_name='grid.v1.AzureClusterDriverSpec.region',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='region',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='subscription_id',
            full_name='grid.v1.AzureClusterDriverSpec.subscription_id',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='subscriptionId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes_version',
            full_name='grid.v1.AzureClusterDriverSpec.kubernetes_version',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetesVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='instance_types',
            full_name='grid.v1.AzureClusterDriverSpec.instance_types',
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='instanceTypes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal_test_cluster',
            full_name='grid.v1.AzureClusterDriverSpec.internal_test_cluster',
            index=4,
            number=18,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internalTestCluster',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1605,
    serialized_end=1855,
)

_INSTANCESPEC = _descriptor.Descriptor(
    name='InstanceSpec',
    full_name='grid.v1.InstanceSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='name',
            full_name='grid.v1.InstanceSpec.name',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='name',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1857,
    serialized_end=1891,
)

_EXTERNALKUBECONFIG = _descriptor.Descriptor(
    name='ExternalKubeconfig',
    full_name='grid.v1.ExternalKubeconfig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='kubeconfig',
            full_name='grid.v1.ExternalKubeconfig.kubeconfig',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubeconfig',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1893,
    serialized_end=1945,
)

_SLURMCLUSTERDRIVER = _descriptor.Descriptor(
    name='SlurmClusterDriver',
    full_name='grid.v1.SlurmClusterDriver',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1947,
    serialized_end=1967,
)

_CLUSTERSTATUS = _descriptor.Descriptor(
    name='ClusterStatus',
    full_name='grid.v1.ClusterStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='driver_status',
            full_name='grid.v1.ClusterStatus.driver_status',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='driverStatus',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phase',
            full_name='grid.v1.ClusterStatus.phase',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phase',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='reason',
            full_name='grid.v1.ClusterStatus.reason',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='reason',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='last_healthcheck_timestamp',
            full_name='grid.v1.ClusterStatus.last_healthcheck_timestamp',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='lastHealthcheckTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1970,
    serialized_end=2211,
)

_CLUSTERDRIVERSTATUS = _descriptor.Descriptor(
    name='ClusterDriverStatus',
    full_name='grid.v1.ClusterDriverStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ClusterDriverStatus.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes',
            full_name='grid.v1.ClusterDriverStatus.kubernetes',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='slurm',
            full_name='grid.v1.ClusterDriverStatus.slurm',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='slurm',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='status',
            full_name='grid.v1.ClusterDriverStatus.status',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=2214,
    serialized_end=2418,
)

_KUBERNETESCLUSTERSTATUS = _descriptor.Descriptor(
    name='KubernetesClusterStatus',
    full_name='grid.v1.KubernetesClusterStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='bastion_host_ip',
            full_name='grid.v1.KubernetesClusterStatus.bastion_host_ip',
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='bastionHostIp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ssh_public_key',
            full_name='grid.v1.KubernetesClusterStatus.ssh_public_key',
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshPublicKey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ssh_private_key',
            full_name='grid.v1.KubernetesClusterStatus.ssh_private_key',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshPrivateKey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='eks',
            full_name='grid.v1.KubernetesClusterStatus.eks',
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='eks',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='azure',
            full_name='grid.v1.KubernetesClusterStatus.azure',
            index=4,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='azure',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ingress_load_balancer_hostname',
            full_name='grid.v1.KubernetesClusterStatus.ingress_load_balancer_hostname',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='ingressLoadBalancerHostname',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ingress_load_balancer_ip',
            full_name='grid.v1.KubernetesClusterStatus.ingress_load_balancer_ip',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='ingressLoadBalancerIp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ssh_gateway_hostname',
            full_name='grid.v1.KubernetesClusterStatus.ssh_gateway_hostname',
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sshGatewayHostname',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ingress_ca_cert',
            full_name='grid.v1.KubernetesClusterStatus.ingress_ca_cert',
            index=8,
            number=10,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='ingressCaCert',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='driver_status',
            full_name='grid.v1.KubernetesClusterStatus.driver_status',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
        _descriptor.OneofDescriptor(
            name='ingress',
            full_name='grid.v1.KubernetesClusterStatus.ingress',
            index=1,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=2421,
    serialized_end=2923,
)

_EKSCUSTERDRIVERSTATUS = _descriptor.Descriptor(
    name='EKSCusterDriverStatus',
    full_name='grid.v1.EKSCusterDriverStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='gridlet_role_arn',
            full_name='grid.v1.EKSCusterDriverStatus.gridlet_role_arn',
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='gridletRoleArn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_workload_role_arn',
            full_name='grid.v1.EKSCusterDriverStatus.user_workload_role_arn',
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userWorkloadRoleArn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ecr_registry_id',
            full_name='grid.v1.EKSCusterDriverStatus.ecr_registry_id',
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='ecrRegistryId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='ecr_repository_uri',
            full_name='grid.v1.EKSCusterDriverStatus.ecr_repository_uri',
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='ecrRepositoryUri',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='vpc_id',
            full_name='grid.v1.EKSCusterDriverStatus.vpc_id',
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='vpcId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2926,
    serialized_end=3153,
)

_AZURECLUSTERDRIVERSTATUS = _descriptor.Descriptor(
    name='AzureClusterDriverStatus',
    full_name='grid.v1.AzureClusterDriverStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=3155,
    serialized_end=3181,
)

_SLURMCLUSTERSTATUS = _descriptor.Descriptor(
    name='SlurmClusterStatus',
    full_name='grid.v1.SlurmClusterStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=3183,
    serialized_end=3203,
)

_CLUSTER.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_CLUSTER.fields_by_name['spec'].message_type = _CLUSTERSPEC
_CLUSTER.fields_by_name['status'].message_type = _CLUSTERSTATUS
_CLUSTERSPEC.fields_by_name['driver'].message_type = _CLUSTERDRIVER
_CLUSTERSPEC.fields_by_name['desired_state'].enum_type = _CLUSTERSTATE
_CLUSTERSPEC.fields_by_name['cluster_type'].enum_type = _CLUSTERTYPE
_CLUSTERDRIVER.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERDRIVER.fields_by_name['kubernetes'].message_type = _KUBERNETESCLUSTERDRIVER
_CLUSTERDRIVER.fields_by_name['slurm'].message_type = _SLURMCLUSTERDRIVER
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_CLUSTERDRIVER.fields_by_name['external'])
_CLUSTERDRIVER.fields_by_name['external'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_CLUSTERDRIVER.fields_by_name['kubernetes'])
_CLUSTERDRIVER.fields_by_name['kubernetes'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_CLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_CLUSTERDRIVER.fields_by_name['slurm'])
_CLUSTERDRIVER.fields_by_name['slurm'].containing_oneof = _CLUSTERDRIVER.oneofs_by_name['driver']
_KUBERNETESCLUSTERDRIVER.fields_by_name['aws'].message_type = _AWSCLUSTERDRIVERSPEC
_KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'].message_type = _EXTERNALKUBECONFIG
_KUBERNETESCLUSTERDRIVER.fields_by_name['azure'].message_type = _AZURECLUSTERDRIVERSPEC
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_KUBERNETESCLUSTERDRIVER.fields_by_name['aws'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['aws'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver']
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['kubeconfig'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name[
    'driver']
_KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver'].fields.append(_KUBERNETESCLUSTERDRIVER.fields_by_name['azure'])
_KUBERNETESCLUSTERDRIVER.fields_by_name['azure'].containing_oneof = _KUBERNETESCLUSTERDRIVER.oneofs_by_name['driver']
_AWSCLUSTERDRIVERSPEC.fields_by_name['instance_types'].message_type = _INSTANCESPEC
_AZURECLUSTERDRIVERSPEC.fields_by_name['instance_types'].message_type = _INSTANCESPEC
_CLUSTERSTATUS.fields_by_name['driver_status'].message_type = _CLUSTERDRIVERSTATUS
_CLUSTERSTATUS.fields_by_name['phase'].enum_type = _CLUSTERSTATE
_CLUSTERSTATUS.fields_by_name['last_healthcheck_timestamp'
                              ].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTERDRIVERSTATUS.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'].message_type = _KUBERNETESCLUSTERSTATUS
_CLUSTERDRIVERSTATUS.fields_by_name['slurm'].message_type = _SLURMCLUSTERSTATUS
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(_CLUSTERDRIVERSTATUS.fields_by_name['external'])
_CLUSTERDRIVERSTATUS.fields_by_name['external'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(_CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'])
_CLUSTERDRIVERSTATUS.fields_by_name['kubernetes'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_CLUSTERDRIVERSTATUS.oneofs_by_name['status'].fields.append(_CLUSTERDRIVERSTATUS.fields_by_name['slurm'])
_CLUSTERDRIVERSTATUS.fields_by_name['slurm'].containing_oneof = _CLUSTERDRIVERSTATUS.oneofs_by_name['status']
_KUBERNETESCLUSTERSTATUS.fields_by_name['eks'].message_type = _EKSCUSTERDRIVERSTATUS
_KUBERNETESCLUSTERSTATUS.fields_by_name['azure'].message_type = _AZURECLUSTERDRIVERSTATUS
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status'].fields.append(_KUBERNETESCLUSTERSTATUS.fields_by_name['eks'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['eks'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name[
    'driver_status']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['driver_status'].fields.append(_KUBERNETESCLUSTERSTATUS.fields_by_name['azure'])
_KUBERNETESCLUSTERSTATUS.fields_by_name['azure'].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name[
    'driver_status']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress'].fields.append(
    _KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_hostname']
)
_KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_hostname'
                                        ].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress']
_KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress'].fields.append(
    _KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_ip']
)
_KUBERNETESCLUSTERSTATUS.fields_by_name['ingress_load_balancer_ip'
                                        ].containing_oneof = _KUBERNETESCLUSTERSTATUS.oneofs_by_name['ingress']
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['ClusterSpec'] = _CLUSTERSPEC
DESCRIPTOR.message_types_by_name['ClusterDriver'] = _CLUSTERDRIVER
DESCRIPTOR.message_types_by_name['KubernetesClusterDriver'] = _KUBERNETESCLUSTERDRIVER
DESCRIPTOR.message_types_by_name['AWSClusterDriverSpec'] = _AWSCLUSTERDRIVERSPEC
DESCRIPTOR.message_types_by_name['AzureClusterDriverSpec'] = _AZURECLUSTERDRIVERSPEC
DESCRIPTOR.message_types_by_name['InstanceSpec'] = _INSTANCESPEC
DESCRIPTOR.message_types_by_name['ExternalKubeconfig'] = _EXTERNALKUBECONFIG
DESCRIPTOR.message_types_by_name['SlurmClusterDriver'] = _SLURMCLUSTERDRIVER
DESCRIPTOR.message_types_by_name['ClusterStatus'] = _CLUSTERSTATUS
DESCRIPTOR.message_types_by_name['ClusterDriverStatus'] = _CLUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['KubernetesClusterStatus'] = _KUBERNETESCLUSTERSTATUS
DESCRIPTOR.message_types_by_name['EKSCusterDriverStatus'] = _EKSCUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['AzureClusterDriverStatus'] = _AZURECLUSTERDRIVERSTATUS
DESCRIPTOR.message_types_by_name['SlurmClusterStatus'] = _SLURMCLUSTERSTATUS
DESCRIPTOR.enum_types_by_name['ClusterType'] = _CLUSTERTYPE
DESCRIPTOR.enum_types_by_name['ClusterState'] = _CLUSTERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType(
    'Cluster',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CLUSTER,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Cluster)
    }
)
_sym_db.RegisterMessage(Cluster)

ClusterSpec = _reflection.GeneratedProtocolMessageType(
    'ClusterSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CLUSTERSPEC,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ClusterSpec)
    }
)
_sym_db.RegisterMessage(ClusterSpec)

ClusterDriver = _reflection.GeneratedProtocolMessageType(
    'ClusterDriver',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CLUSTERDRIVER,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ClusterDriver)
    }
)
_sym_db.RegisterMessage(ClusterDriver)

KubernetesClusterDriver = _reflection.GeneratedProtocolMessageType(
    'KubernetesClusterDriver',
    (_message.Message, ),
    {
        'DESCRIPTOR': _KUBERNETESCLUSTERDRIVER,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.KubernetesClusterDriver)
    }
)
_sym_db.RegisterMessage(KubernetesClusterDriver)

AWSClusterDriverSpec = _reflection.GeneratedProtocolMessageType(
    'AWSClusterDriverSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _AWSCLUSTERDRIVERSPEC,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.AWSClusterDriverSpec)
    }
)
_sym_db.RegisterMessage(AWSClusterDriverSpec)

AzureClusterDriverSpec = _reflection.GeneratedProtocolMessageType(
    'AzureClusterDriverSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _AZURECLUSTERDRIVERSPEC,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.AzureClusterDriverSpec)
    }
)
_sym_db.RegisterMessage(AzureClusterDriverSpec)

InstanceSpec = _reflection.GeneratedProtocolMessageType(
    'InstanceSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _INSTANCESPEC,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.InstanceSpec)
    }
)
_sym_db.RegisterMessage(InstanceSpec)

ExternalKubeconfig = _reflection.GeneratedProtocolMessageType(
    'ExternalKubeconfig',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXTERNALKUBECONFIG,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExternalKubeconfig)
    }
)
_sym_db.RegisterMessage(ExternalKubeconfig)

SlurmClusterDriver = _reflection.GeneratedProtocolMessageType(
    'SlurmClusterDriver',
    (_message.Message, ),
    {
        'DESCRIPTOR': _SLURMCLUSTERDRIVER,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.SlurmClusterDriver)
    }
)
_sym_db.RegisterMessage(SlurmClusterDriver)

ClusterStatus = _reflection.GeneratedProtocolMessageType(
    'ClusterStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CLUSTERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ClusterStatus)
    }
)
_sym_db.RegisterMessage(ClusterStatus)

ClusterDriverStatus = _reflection.GeneratedProtocolMessageType(
    'ClusterDriverStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CLUSTERDRIVERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ClusterDriverStatus)
    }
)
_sym_db.RegisterMessage(ClusterDriverStatus)

KubernetesClusterStatus = _reflection.GeneratedProtocolMessageType(
    'KubernetesClusterStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _KUBERNETESCLUSTERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.KubernetesClusterStatus)
    }
)
_sym_db.RegisterMessage(KubernetesClusterStatus)

EKSCusterDriverStatus = _reflection.GeneratedProtocolMessageType(
    'EKSCusterDriverStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EKSCUSTERDRIVERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.EKSCusterDriverStatus)
    }
)
_sym_db.RegisterMessage(EKSCusterDriverStatus)

AzureClusterDriverStatus = _reflection.GeneratedProtocolMessageType(
    'AzureClusterDriverStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _AZURECLUSTERDRIVERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.AzureClusterDriverStatus)
    }
)
_sym_db.RegisterMessage(AzureClusterDriverStatus)

SlurmClusterStatus = _reflection.GeneratedProtocolMessageType(
    'SlurmClusterStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _SLURMCLUSTERSTATUS,
        '__module__': 'grid.v1.cluster_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.SlurmClusterStatus)
    }
)
_sym_db.RegisterMessage(SlurmClusterStatus)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import cluster_service_pb2 as grid_dot_v1_dot_cluster__service__pb2


class ClusterServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateCluster = channel.unary_unary(
            '/grid.v1.ClusterService/CreateCluster',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterResponse.FromString,
        )
        self.GetCluster = channel.unary_unary(
            '/grid.v1.ClusterService/GetCluster',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterResponse.FromString,
        )
        self.ListClusters = channel.unary_unary(
            '/grid.v1.ClusterService/ListClusters',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersResponse.FromString,
        )
        self.UpdateCluster = channel.unary_unary(
            '/grid.v1.ClusterService/UpdateCluster',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterResponse.FromString,
        )
        self.UpdateClusterStatus = channel.unary_unary(
            '/grid.v1.ClusterService/UpdateClusterStatus',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusResponse.FromString,
        )
        self.DeleteCluster = channel.unary_unary(
            '/grid.v1.ClusterService/DeleteCluster',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
        )
        self.WatchClusters = channel.unary_stream(
            '/grid.v1.ClusterService/WatchClusters',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersResponse.FromString,
        )
        self.QueryClusterLogs = channel.unary_unary(
            '/grid.v1.ClusterService/QueryClusterLogs',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsResponse.FromString,
        )
        self.TailClusterLogs = channel.unary_stream(
            '/grid.v1.ClusterService/TailClusterLogs',
            request_serializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsResponse.FromString,
        )


class ClusterServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateCluster(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCluster(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClusterStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCluster(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchClusters(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryClusterLogs(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TailClusterLogs(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateCluster':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateCluster,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.CreateClusterResponse.SerializeToString,
        ),
        'GetCluster':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetCluster,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.GetClusterResponse.SerializeToString,
        ),
        'ListClusters':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListClusters,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
        ),
        'UpdateCluster':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateCluster,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterResponse.SerializeToString,
        ),
        'UpdateClusterStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateClusterStatus,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.UpdateClusterStatusResponse.SerializeToString,
        ),
        'DeleteCluster':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteCluster,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.DeleteClusterResponse.SerializeToString,
        ),
        'WatchClusters':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchClusters,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.WatchClustersResponse.SerializeToString,
        ),
        'QueryClusterLogs':
        grpc.unary_unary_rpc_method_handler(
            servicer.QueryClusterLogs,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.QueryClusterLogsResponse.SerializeToString,
        ),
        'TailClusterLogs':
        grpc.unary_stream_rpc_method_handler(
            servicer.TailClusterLogs,
            request_deserializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsRequest.FromString,
            response_serializer=grid_dot_v1_dot_cluster__service__pb2.TailClusterLogsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.ClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/resource.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x16grid/v1/resource.proto\x12\x07grid.v1\"\xbd\x01\n\tResources\x12\x10\n\x03\x63pu\x18\x01 \x01(\x04R\x03\x63pu\x12\x10\n\x03gpu\x18\x02 \x01(\x04R\x03gpu\x12\x1d\n\nstorage_gb\x18\x03 \x01(\x04R\tstorageGb\x12\x33\n\x05\x65xtra\x18\x04 \x03(\x0b\x32\x1d.grid.v1.Resources.ExtraEntryR\x05\x65xtra\x1a\x38\n\nExtraEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_RESOURCES_EXTRAENTRY = _descriptor.Descriptor(
    name='ExtraEntry',
    full_name='grid.v1.Resources.ExtraEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.Resources.ExtraEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.Resources.ExtraEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=169,
    serialized_end=225,
)

_RESOURCES = _descriptor.Descriptor(
    name='Resources',
    full_name='grid.v1.Resources',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cpu',
            full_name='grid.v1.Resources.cpu',
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cpu',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='gpu',
            full_name='grid.v1.Resources.gpu',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='gpu',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='storage_gb',
            full_name='grid.v1.Resources.storage_gb',
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='storageGb',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='extra',
            full_name='grid.v1.Resources.extra',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='extra',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[
        _RESOURCES_EXTRAENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=36,
    serialized_end=225,
)

_RESOURCES_EXTRAENTRY.containing_type = _RESOURCES
_RESOURCES.fields_by_name['extra'].message_type = _RESOURCES_EXTRAENTRY
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resources = _reflection.GeneratedProtocolMessageType(
    'Resources',
    (_message.Message, ),
    {
        'ExtraEntry':
        _reflection.GeneratedProtocolMessageType(
            'ExtraEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _RESOURCES_EXTRAENTRY,
                '__module__': 'grid.v1.resource_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.Resources.ExtraEntry)
            }
        ),
        'DESCRIPTOR':
        _RESOURCES,
        '__module__':
        'grid.v1.resource_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Resources)
    }
)
_sym_db.RegisterMessage(Resources)
_sym_db.RegisterMessage(Resources.ExtraEntry)

DESCRIPTOR._options = None
_RESOURCES_EXTRAENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/metadata.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x16grid/v1/metadata.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x04\n\x08Metadata\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12I\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x63reationTimestamp\x12I\n\x12\x64\x65letion_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x64\x65letionTimestamp\x12)\n\x10resource_version\x18\x05 \x01(\tR\x0fresourceVersion\x12\x35\n\x06labels\x18\x06 \x03(\x0b\x32\x1d.grid.v1.Metadata.LabelsEntryR\x06labels\x12\x44\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32\".grid.v1.Metadata.AnnotationsEntryR\x0b\x61nnotations\x12\x1e\n\nfinalizers\x18\x08 \x03(\tR\nfinalizers\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x8c\x01\n\x0eWatchEventType\x12 \n\x1cWATCH_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18WATCH_EVENT_TYPE_CREATED\x10\x01\x12\x1c\n\x18WATCH_EVENT_TYPE_UPDATED\x10\x02\x12\x1c\n\x18WATCH_EVENT_TYPE_DELETED\x10\x03\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ]
)

_WATCHEVENTTYPE = _descriptor.EnumDescriptor(
    name='WatchEventType',
    full_name='grid.v1.WatchEventType',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='WATCH_EVENT_TYPE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='WATCH_EVENT_TYPE_CREATED',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='WATCH_EVENT_TYPE_UPDATED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='WATCH_EVENT_TYPE_DELETED',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=591,
    serialized_end=731,
)
_sym_db.RegisterEnumDescriptor(_WATCHEVENTTYPE)

WatchEventType = enum_type_wrapper.EnumTypeWrapper(_WATCHEVENTTYPE)
WATCH_EVENT_TYPE_UNSPECIFIED = 0
WATCH_EVENT_TYPE_CREATED = 1
WATCH_EVENT_TYPE_UPDATED = 2
WATCH_EVENT_TYPE_DELETED = 3

_METADATA_LABELSENTRY = _descriptor.Descriptor(
    name='LabelsEntry',
    full_name='grid.v1.Metadata.LabelsEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.Metadata.LabelsEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.Metadata.LabelsEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=467,
    serialized_end=524,
)

_METADATA_ANNOTATIONSENTRY = _descriptor.Descriptor(
    name='AnnotationsEntry',
    full_name='grid.v1.Metadata.AnnotationsEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.Metadata.AnnotationsEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.Metadata.AnnotationsEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=526,
    serialized_end=588,
)

_METADATA = _descriptor.Descriptor(
    name='Metadata',
    full_name='grid.v1.Metadata',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.Metadata.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='name',
            full_name='grid.v1.Metadata.name',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='name',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='creation_timestamp',
            full_name='grid.v1.Metadata.creation_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='creationTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='deletion_timestamp',
            full_name='grid.v1.Metadata.deletion_timestamp',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='deletionTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.Metadata.resource_version',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='labels',
            full_name='grid.v1.Metadata.labels',
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='labels',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='annotations',
            full_name='grid.v1.Metadata.annotations',
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='annotations',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='finalizers',
            full_name='grid.v1.Metadata.finalizers',
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='finalizers',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[
        _METADATA_LABELSENTRY,
        _METADATA_ANNOTATIONSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=69,
    serialized_end=588,
)

_METADATA_LABELSENTRY.containing_type = _METADATA
_METADATA_ANNOTATIONSENTRY.containing_type = _METADATA
_METADATA.fields_by_name['creation_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name['deletion_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name['labels'].message_type = _METADATA_LABELSENTRY
_METADATA.fields_by_name['annotations'].message_type = _METADATA_ANNOTATIONSENTRY
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.enum_types_by_name['WatchEventType'] = _WATCHEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metadata = _reflection.GeneratedProtocolMessageType(
    'Metadata',
    (_message.Message, ),
    {
        'LabelsEntry':
        _reflection.GeneratedProtocolMessageType(
            'LabelsEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _METADATA_LABELSENTRY,
                '__module__': 'grid.v1.metadata_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.Metadata.LabelsEntry)
            }
        ),
        'AnnotationsEntry':
        _reflection.GeneratedProtocolMessageType(
            'AnnotationsEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _METADATA_ANNOTATIONSENTRY,
                '__module__': 'grid.v1.metadata_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.Metadata.AnnotationsEntry)
            }
        ),
        'DESCRIPTOR':
        _METADATA,
        '__module__':
        'grid.v1.metadata_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Metadata)
    }
)
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.LabelsEntry)
_sym_db.RegisterMessage(Metadata.AnnotationsEntry)

DESCRIPTOR._options = None
_METADATA_LABELSENTRY._options = None
_METADATA_ANNOTATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/user.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x12grid/v1/user.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x01\n\x04User\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12.\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x14.grid.v1.UserDetailsR\x07\x64\x65tails\x12+\n\x06status\x18\x03 \x01(\x0b\x32\x13.grid.v1.UserStatusR\x06status\"\x9b\x03\n\x0bUserDetails\x12#\n\rauth_provider\x18\x01 \x01(\tR\x0c\x61uthProvider\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12*\n\x08\x61pi_keys\x18\x06 \x03(\x0b\x32\x0f.grid.v1.ApiKeyR\x07\x61piKeys\x12\x1f\n\x0bpicture_url\x18\x07 \x01(\tR\npictureUrl\x12\x1a\n\x08internal\x18\x0b \x01(\x08R\x08internal\x12!\n\x0cphone_number\x18\x0c \x01(\tR\x0bphoneNumber\x12\x31\n\x08\x66\x65\x61tures\x18\r \x01(\x0b\x32\x15.grid.v1.UserFeaturesR\x08\x66\x65\x61tures\x12:\n\x0bpreferences\x18\x0e \x01(\x0b\x32\x18.grid.v1.UserPreferencesR\x0bpreferences\"1\n\x0cUserFeatures\x12!\n\x0c\x62yoc_enabled\x18\x01 \x01(\x08R\x0b\x62yocEnabled\"?\n\x0fUserPreferences\x12,\n\x12\x64\x65\x66\x61ult_cluster_id\x18\x02 \x01(\tR\x10\x64\x65\x66\x61ultClusterId\"\xca\x01\n\x06\x41piKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12#\n\rsecret_sha256\x18\x02 \x01(\x0cR\x0csecretSha256\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x37\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastUsed\x12\x17\n\x07raw_key\x18\x05 \x01(\tR\x06rawKey\"\xa5\x01\n\x12VerificationStatus\x12\x1f\n\x0bis_verified\x18\x01 \x01(\x08R\nisVerified\x12\x31\n\x14verification_channel\x18\x02 \x01(\tR\x13verificationChannel\x12;\n\x0bverified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nverifiedAt\"\xec\x01\n\nUserStatus\x12%\n\x0einstalled_grid\x18\x01 \x01(\x08R\rinstalledGrid\x12)\n\x10\x63ompleted_signup\x18\x02 \x01(\x08R\x0f\x63ompletedSignup\x12\x1f\n\x0b\x63li_version\x18\x03 \x01(\tR\ncliVersion\x12\x1d\n\nis_blocked\x18\x04 \x01(\x08R\tisBlocked\x12L\n\x13verification_status\x18\x05 \x01(\x0b\x32\x1b.grid.v1.VerificationStatusR\x12verificationStatusB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ]
)

_USER = _descriptor.Descriptor(
    name='User',
    full_name='grid.v1.User',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.User.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='details',
            full_name='grid.v1.User.details',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='details',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.User.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=89,
    serialized_end=235,
)

_USERDETAILS = _descriptor.Descriptor(
    name='UserDetails',
    full_name='grid.v1.UserDetails',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='auth_provider',
            full_name='grid.v1.UserDetails.auth_provider',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='authProvider',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='username',
            full_name='grid.v1.UserDetails.username',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='username',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='first_name',
            full_name='grid.v1.UserDetails.first_name',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='firstName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='last_name',
            full_name='grid.v1.UserDetails.last_name',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='lastName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='email',
            full_name='grid.v1.UserDetails.email',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='email',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='api_keys',
            full_name='grid.v1.UserDetails.api_keys',
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='apiKeys',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='picture_url',
            full_name='grid.v1.UserDetails.picture_url',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='pictureUrl',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='internal',
            full_name='grid.v1.UserDetails.internal',
            index=7,
            number=11,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='internal',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='phone_number',
            full_name='grid.v1.UserDetails.phone_number',
            index=8,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phoneNumber',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='features',
            full_name='grid.v1.UserDetails.features',
            index=9,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='features',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='preferences',
            full_name='grid.v1.UserDetails.preferences',
            index=10,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='preferences',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=238,
    serialized_end=649,
)

_USERFEATURES = _descriptor.Descriptor(
    name='UserFeatures',
    full_name='grid.v1.UserFeatures',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='byoc_enabled',
            full_name='grid.v1.UserFeatures.byoc_enabled',
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='byocEnabled',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=651,
    serialized_end=700,
)

_USERPREFERENCES = _descriptor.Descriptor(
    name='UserPreferences',
    full_name='grid.v1.UserPreferences',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='default_cluster_id',
            full_name='grid.v1.UserPreferences.default_cluster_id',
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='defaultClusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=702,
    serialized_end=765,
)

_APIKEY = _descriptor.Descriptor(
    name='ApiKey',
    full_name='grid.v1.ApiKey',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.ApiKey.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='secret_sha256',
            full_name='grid.v1.ApiKey.secret_sha256',
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='secretSha256',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='created_at',
            full_name='grid.v1.ApiKey.created_at',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='createdAt',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='last_used',
            full_name='grid.v1.ApiKey.last_used',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='lastUsed',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='raw_key',
            full_name='grid.v1.ApiKey.raw_key',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='rawKey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=768,
    serialized_end=970,
)

_VERIFICATIONSTATUS = _descriptor.Descriptor(
    name='VerificationStatus',
    full_name='grid.v1.VerificationStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='is_verified',
            full_name='grid.v1.VerificationStatus.is_verified',
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='isVerified',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='verification_channel',
            full_name='grid.v1.VerificationStatus.verification_channel',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='verificationChannel',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='verified_at',
            full_name='grid.v1.VerificationStatus.verified_at',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='verifiedAt',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=973,
    serialized_end=1138,
)

_USERSTATUS = _descriptor.Descriptor(
    name='UserStatus',
    full_name='grid.v1.UserStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='installed_grid',
            full_name='grid.v1.UserStatus.installed_grid',
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='installedGrid',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='completed_signup',
            full_name='grid.v1.UserStatus.completed_signup',
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='completedSignup',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cli_version',
            full_name='grid.v1.UserStatus.cli_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='cliVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='is_blocked',
            full_name='grid.v1.UserStatus.is_blocked',
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='isBlocked',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='verification_status',
            full_name='grid.v1.UserStatus.verification_status',
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='verificationStatus',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1141,
    serialized_end=1377,
)

_USER.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_USER.fields_by_name['details'].message_type = _USERDETAILS
_USER.fields_by_name['status'].message_type = _USERSTATUS
_USERDETAILS.fields_by_name['api_keys'].message_type = _APIKEY
_USERDETAILS.fields_by_name['features'].message_type = _USERFEATURES
_USERDETAILS.fields_by_name['preferences'].message_type = _USERPREFERENCES
_APIKEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_APIKEY.fields_by_name['last_used'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VERIFICATIONSTATUS.fields_by_name['verified_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USERSTATUS.fields_by_name['verification_status'].message_type = _VERIFICATIONSTATUS
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['UserDetails'] = _USERDETAILS
DESCRIPTOR.message_types_by_name['UserFeatures'] = _USERFEATURES
DESCRIPTOR.message_types_by_name['UserPreferences'] = _USERPREFERENCES
DESCRIPTOR.message_types_by_name['ApiKey'] = _APIKEY
DESCRIPTOR.message_types_by_name['VerificationStatus'] = _VERIFICATIONSTATUS
DESCRIPTOR.message_types_by_name['UserStatus'] = _USERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

User = _reflection.GeneratedProtocolMessageType(
    'User',
    (_message.Message, ),
    {
        'DESCRIPTOR': _USER,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.User)
    }
)
_sym_db.RegisterMessage(User)

UserDetails = _reflection.GeneratedProtocolMessageType(
    'UserDetails',
    (_message.Message, ),
    {
        'DESCRIPTOR': _USERDETAILS,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UserDetails)
    }
)
_sym_db.RegisterMessage(UserDetails)

UserFeatures = _reflection.GeneratedProtocolMessageType(
    'UserFeatures',
    (_message.Message, ),
    {
        'DESCRIPTOR': _USERFEATURES,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UserFeatures)
    }
)
_sym_db.RegisterMessage(UserFeatures)

UserPreferences = _reflection.GeneratedProtocolMessageType(
    'UserPreferences',
    (_message.Message, ),
    {
        'DESCRIPTOR': _USERPREFERENCES,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UserPreferences)
    }
)
_sym_db.RegisterMessage(UserPreferences)

ApiKey = _reflection.GeneratedProtocolMessageType(
    'ApiKey',
    (_message.Message, ),
    {
        'DESCRIPTOR': _APIKEY,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ApiKey)
    }
)
_sym_db.RegisterMessage(ApiKey)

VerificationStatus = _reflection.GeneratedProtocolMessageType(
    'VerificationStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _VERIFICATIONSTATUS,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.VerificationStatus)
    }
)
_sym_db.RegisterMessage(VerificationStatus)

UserStatus = _reflection.GeneratedProtocolMessageType(
    'UserStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _USERSTATUS,
        '__module__': 'grid.v1.user_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UserStatus)
    }
)
_sym_db.RegisterMessage(UserStatus)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
